This library allows you to convert currencies at current rates using open APIs.

LIBRARIES USED:
- pandas
- openpyxl
- requests
Install for the library to work correctly.

HOW TO USE:

- To enable/disable debug messages, use:
convcur.mngdebug = True (or False)
(Messages are disabled by default)

- To assign variables, use:
manager.setp("name", value, "CURRENCY")
Usage example:
manager.setp("Laptop", 200, "USD")

- To call a variable, use:
convcur.manager.name.CURRENCY
Usage example:
print(manager.Laptop.USD)
>>>200.0

- To convert a variable to a different currency, change the currency value in the existing variable to the desired one. Example:
print(manager.Laptop.EUR)
>>>173.24

- To force a currency.xlsx update, use force_update=True in CurrencyManager(). Example:
manager = convcur.CurrencyManager(force_update=True)

EXAMPLE PROGRAM:

import convcur
convcur.mngdebug = True
manager = convcur.CurrencyManager()
manager.setp("Laptop", 200, "USD")
print(manager.Laptop.EUR)

IMPORTANT:

- Internet access is required to create/update currencies.xlsx. If you don't have currencies.xlsx created, you can use USD, EUR, JPY, GBP, and CNY (they won't update without internet access).